{% load navsy_tags %}
{% spaceless %}
<div class="navsy-breadcrumbs">
    <ul>
        {% for page in breadcrumbs %}
            <li class="{% navsy_is page 'active' %}"><a href="{{ page.url }}">{% if not page.is_home %}{{ page.name }}{% endif %}</a></li>
        {% endfor %}
    </ul>
</div>
{% endspaceless %}