{% load navsy_tags static %}
<!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8"/>
        <meta content="ie=edge" http-equiv="x-ua-compatible"/>
        <meta content="width=device-width, initial-scale=1.0" name="viewport"/>
        {% navsy_title base="django-navsy - Navigation system for lazy devs." html=True %}
        {% navsy_languages_alternate_href %}
        <link rel="stylesheet" href="{% static 'navsy/css/default.css' %}" />
    </head>
    <body>

        <h1 class="h2"><a href="{% url 'admin:app_list' 'navsy' %}">django-navsy</a></h1>
        <p>Navigation system for lazy devs. [<a class="github" href="http://github.com/fabiocaccamo/django-navsy" target="_blank">GitHub</a>]</p>

        {% if navsy_multilanguage %}
        <div class="languages-wrapper">
            <h2 class="h5">Languages:</h2>
            {% navsy_languages_menu label="name" select=True %}
            {# {% navsy_languages_menu label="code" select=True %} #}
            {# {% navsy_languages_menu label="name" %} #}
            {# {% navsy_languages_menu label="short_name" %}  #}
            {% navsy_languages_menu label="code" %}
            {# {% navsy_languages_menu label="code" languages="en it" %} #}
        </div>
        {% endif %}

        <div class="breadcrumbs-wrapper">
            <h2 class="h5">Breadcrumbs:</h2>
            {% navsy_breadcrumbs %}
        </div>

        <div class="menu-wrapper">
            <h2 class="h5"><a href="{% url 'admin:navsy_page_changelist' %}">Menu</a>:</h2>
            {# {% navsy_menu select=True label="name" %} #}
            {# {% navsy_menu select=True label="path" %} #}
            {# {% navsy_menu select=True label="dash" %} #}
            {% navsy_menu select=True label="tabs" %}
            {# {% navsy_menu select=True levels=1 %} #}
            {% navsy_menu %}
        </div>

        <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.2.1/jquery.min.js"></script>

    </body>
</html>

