{% spaceless %}
<div class="navsy-pagination">
    <ul>
        {% for page in pages_count %}
            <li class="{% navsy_is page 'current' %}"><a href="{{ page.url }}">{{ page.name }}</a></li>
        {% endfor %}
    </ul>
</div>
{% endspaceless %}